function F = FminWeakSep(p,x,sep)
% Fmin(p,x) gives the lowest F parameter such
% that the data satisfy the weak sep inequalities using a binary search procedure
%
% REQUIRES the procedure WeakSepF
%

[T,K] = size(p); %T is number of observations, K is the number of goods

% SEPARABLE GROUP

r = p(:,sep);                              % prices in separable group
y = x(:,sep);                              % quantities in separable group

if size(sep,2) == 1; 
   ESEP = max(r.*y);
else; 
   ESEP = max(sum((r.*y)')');
end;
    

% NON-SEPARABLE GROUP

nsep = (1:K)';
nsep(sep)=[];               % goods in non-separable group

z = p(:,nsep);                              % prices in non-separable group
w = x(:,nsep);                              % quantities in non-separable group

if size(nsep,2) == 1; 
    ENSEP = max(z.*w);
else; 
    ENSEP = max(sum((z.*w)')');
end;


%check for weak sep consistency: yes => F = 0

if CDDH_F(p,x,sep,0)==1;
    F = 0;
else
    
    Fupper = max([ESEP ENSEP]); % feasible upper bound
    Flower = 0;% unfeasible lower bound
     
    
    while (Fupper-Flower)/Flower >= 0.0000001 %change this if accuracy is to be changed
        
        Fevaluate = (Fupper+Flower)/2;%evaluation point
        
        passevaluate = CDDH_F(p,x,sep,Fevaluate);%evaluate this point
        
        if passevaluate == 1 %if it passes add sep
            Fupper = Fevaluate;%new lower bound = evaluation point
            
        elseif passevaluate == 0 %if it does not satisfy add sep
            Flower = Fevaluate;%new upper bound = evaluation point
        end
    end
        F = Fevaluate;
end
    
disp('------------------------------------------------------------------');
disp(['F from LP: ', num2str(F)]);
disp('------------------------------------------------------------------');
