function NUM = garpNUM(p,q,D)

% garpNUM(p,q) calculates the number of GARP violations

T = size(p,1);

% MAKE DRP-MATRIX AND P0-MATRIX
% DRP-matrix has T rows and columns. 
% Element (i,j)=1 if i DRP j (i directly revealed preferred over j)
DRP=eye(T);
P0=zeros(T,T);
for i=1:T
    for j=[1:i-1, i+1:T]
        if p(i,:)*q(i,:)'>=p(i,:)*q(j,:)'
            DRP(i,j)=1;
            if p(i,:)*q(i,:)'>p(i,:)*q(j,:)'
                P0(i,j)=1;
            end % if >
        end % if >=
    end % for j
end % for i

% MAKE RP-MATRIX (TRANSITIVE CLOSURE OF DRP-MATRIX) BY WARSHALL'S ALGORITHM

RP=DRP;
for k=1:T
    for i=[1:k-1, k+1:T] % Iterate through all 'rows' except k
        if RP(i,k)>0     % Only changes possible if (i,k) not 0
            for j=[1:k-1, k+1:T]
                if RP(i,j)==0
                    RP(i,j)=RP(k,j);
                end % if
            end % for j
        end % if
    end % for i
end %for k


% Calculates number of GARP violations
NUM = 0;
NUM_vec = NaN*ones(T*(T-1),2);
for i=1:T
    for j=[1:i-1, i+1:T]
        if RP(i,j) && P0(j,i) % see GARP-definition
            NUM = NUM + 1;
            NUM_vec(NUM,:) = [i j];
        end % if
    end % for j
end % for i

NUM_vec(logical(sum(NUM_vec~=NUM_vec,2)),:)=[];

if D >= 1

disp('------------------------------------------------------------------');
disp(['Number of GARP violations: ', num2str(NUM)]);
disp('------------------------------------------------------------------');

end;

if D == 2;

if NUM>0;
disp('------------------------------------------------------------------');
disp('The problematic observations:');
disp(NUM_vec);
disp('------------------------------------------------------------------');
end;    

end;

